@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: mplayer.pl,v 1.3 2005/11/11 09:33:43 khlut Exp $
+# $Id: mplayer.pl,v 1.4 2005/11/20 05:16:06 khlut Exp $
 # Bind mplayer and mencoder with HTML object
 #
 # Copyright 2005 Elphel, Inc.
@@ -119,7 +119,7 @@ sub ifilt{
     }
 }
 
-sub ofilt_quit{ #child is hang
+sub ofilt_quit{ #child hangs
     $SIG{ALRM}=\&shut;
     kill ALRM, $ifilt;
 }
@@ -169,7 +169,7 @@ sub run_mencoder{
     s/^-+//;
     s/-+$//;
     $fname =~ s/%@/$_/g;
-    $cmd="mencoder -frames $cfg{frames}[0] -fps $v{fps} -ovc copy \"$v{href}\" -o $fname";
+    $cmd="mencoder -frames '$cfg{frames}[0]' -fps '$v{fps}' -ovc copy '$v{href}' -o '$fname'";
     print "cmd=$cmd\n";
     runslv $cmd;
     return $slvp>0;
@@ -189,6 +189,7 @@ while (<>){
 	print "error=1\n";
 	next;
     }
+    s/'/'\\''/g;
     ($x,$y) = split '=', $_, 2;
     $x='href' if($x eq 'src');
     $v{$x}=$y;
@@ -217,11 +218,11 @@ while (<>){
 		    (undef,undef,$v{width},$v{height}) = Gtk2::Gdk::Window->foreign_new(hex $v{xid})->get_geometry;
 		}
 	    }
-	    $OPTS.=" -xy $v{width}"	if( $v{width} && $v{width}!~"%" );
-	    $OPTS.=" -lavdopts lowres=$v{lowres}" if( $v{lowres} );
-	    $OPTS.=" -fps $v{fps}"		if( $v{fps} );
+	    $OPTS.=" -xy '$v{width}'"	if( $v{width} && $v{width}!~"%" );
+	    $OPTS.=" -lavdopts lowres='$v{lowres}'" if( $v{lowres} );
+	    $OPTS.=" -fps '$v{fps}'"		if( $v{fps} );
 	    $OPTS.=" -fixed-vo -loop ".(0+$v{loop}) if( exists $v{loop} );
-	    $cmd="mplayer $OPTS -vo $cfg{vo}[0] -zoom -nojoystick -slave -nomouseinput -cookies \"$v{href}\"";
+	    $cmd="mplayer $OPTS -vo $cfg{vo}[0] -zoom -nojoystick -slave -nomouseinput -cookies '$v{href}'";
 	    print "cmd=$cmd\n";
 	    runslv $cmd;
 	}
